Extraction helpers for decoding emitted observability events.
Functions
- extract_
event - Extracts an
ObservabilityEventfrom a given tracing event, if the event belongs to therig_taptarget and is valid JSON.
Extraction helpers for decoding emitted observability events.
ObservabilityEvent from a given tracing event, if the event
belongs to the rig_tap target and is valid JSON.